Getting started
---------------

``pysarpro`` is an SAR processing Python package that works with
:mod:`numpy` arrays. The package is imported as ``pysarpro``: ::

    >>> import pysarpro as sarpro

Most functions of ``pysarpro`` are found within submodules: ::

    >>> camera = sarpro.data.camera()

A list of submodules and functions is found on the webpage.
